@@ -4,13 +4,13 @@ test_that("solution reduces to sgl when using constant weights, with even groups
   n = 50
   p = 100
   groups = rep(1:20,each=5)
-  data= generate_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
+  data= gen_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
   X <- data$X
   y <- data$y
   # Can't turn off intercept for SGL, so removing it from data
   y = y - mean(y)
   X_center = apply(X,2,mean)
-  X = sapply(1:dim(X)[2], function(i) X[,i] - X_center[i])
+  X = sapply(1:ncol(X), function(i) X[,i] - X_center[i])
   lambda=0.8
   alpha = 0.3
   sgl = SGL::SGL(list(x=X,y=y), index=groups, type = "linear",nlam=1,lambdas=c(0,lambda),alpha=alpha,standardize=FALSE)
@@ -34,13 +34,13 @@ test_that("solution reduces to sgl when using constant weights, with uneven grou
            rep(6:11, each=4),
            rep(12:16, each=5), 
            rep(17:22,each=6))
-  data= generate_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
+  data= gen_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
   X <- data$X
   y <- data$y
   # Can't turn off intercept for SGL, so removing it from data
   y = y - mean(y)
   X_center = apply(X,2,mean)
-  X = sapply(1:dim(X)[2], function(i) X[,i] - X_center[i])
+  X = sapply(1:ncol(X), function(i) X[,i] - X_center[i])
   lambda=0.8
   alpha = 0.3
   sgl = SGL::SGL(list(x=X,y=y), index=groups, type = "linear",nlam=1,lambdas=c(0,lambda),alpha=alpha,standardize=FALSE)
@@ -61,7 +61,7 @@ test_that("solution reduces to sgl when using constant weights, with even groups
   n = 50
   p = 100
   groups = rep(1:20,each=5)
-  data= generate_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
+  data= gen_toy_data(p=p,n=n,rho = 0,seed_id = 4,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
   X <- data$X
   y <- data$y
   lambda=0.8
@@ -83,7 +83,7 @@ test_that("solution reduces to sgl when using constant weights, with even groups
            rep(6:11, each=4),
            rep(12:16, each=5), 
            rep(17:22,each=6))
-  data= generate_toy_data(p=p,n=n,rho = 0,seed_id = 10,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
+  data= gen_toy_data(p=p,n=n,rho = 0,seed_id = 10,grouped = TRUE, groups=groups,group_sparsity=0.3,var_sparsity=0.5,orthogonal = FALSE)
   X <- data$X
   y <- data$y
   lambda=0.8
